
from rest_framework import serializers
from .models import *

class EventSerializer(serializers.ModelSerializer):

    class Meta():
        model = Event
        fields = ('id', 'title', 'description', 'event_picture')

class PerroGrandeSerializer(serializers.ModelSerializer):

    class Meta():
        model = PerroGrande
        fields = ('id', 'totle', 'detalle', 'foto_pichicho')

class GatoSerializer(serializers.ModelSerializer):

    class Meta():
        model = Gato
        fields = ('id', 'title', 'description', 'event_picture')




from rest_framework import viewsets
from .serializers import *
from .models import *

class EventViewSet(viewsets.ModelViewSet):
    queryset = Event.objects.all()
    serializer_class = EventSerializer

class PerroGrandeViewSet(viewsets.ModelViewSet):
    queryset = PerroGrande.objects.all()
    serializer_class = PerroGrandeSerializer

class GatoViewSet(viewsets.ModelViewSet):
    queryset = Gato.objects.all()
    serializer_class = GatoSerializer



#!/usr/bin/env python3

import ast
import astunparse
import re


def create_serializers_and_views():
    with open('lib/models.py', 'r') as file:
        models_ast = ast.parse(file.read())


    serializers_ast = _read_template('serializers')
    views_ast = _read_template('views')
    urls_ast = _read_template('urls')

    model_classes = [clss for clss in models_ast.body if clss.__class__ is ast.ClassDef]

    for mc in model_classes:
        class_fields = [field for field in mc.body if field.__class__ is ast.Assign]

        serializers_ast.body.append(_read_template('serializer', model_class_name=mc.name, 
            field_names=", ".join([f"'{field_name.targets[0].id}'" for field_name in class_fields])))

        views_ast.body.append(_read_template('viewset', model_class_name=mc.name))


        pattern = re.compile(r'(?<!^)(?=[A-Z])')
        mc_name_snake = pattern.sub('-', mc.name).lower()
        urls_ast.body.insert(len(urls_ast.body)-1, _read_template('url', model_class_name=mc.name, model_class_name_snake=mc_name_snake))

    _write_result('lib/serializers.py', serializers_ast)
    _write_result('lib/views.py', views_ast)
    _write_result('lib/urls.py', urls_ast)




def _read_template(template_name, **kwargs):
    with open(f'lib/templates/{template_name}', 'r') as template:
        return ast.parse(template.read().format(**kwargs))

def _write_result(result_file_name, ast_name):
    with open(result_file_name, 'w') as wfile:
        wfile.write(astunparse.unparse(ast_name)) 

if __name__ == '__main__':
    create_serializers_and_views()



from rest_framework.routers import DefaultRouter
from .views import *
router = DefaultRouter()
router.register('event', EventViewSet, basename='event')
router.register('perro-grande', PerroGrandeViewSet, basename='perro-grande')
router.register('gato', GatoViewSet, basename='gato')
urlpatterns = router.urls



from django.db import models

test = 22
class Event(models.Model):
    title = models.TextField(default='Titulo evento')
    description = models.TextField('Descripcion', blank=True, null=True)
    event_picture = models.ImageField(verbose_name='Foto de evento', upload_to='evebt_pictures', blank=True, null=True)

    def __str__(self):
        return self.title

    class Meta:
        verbose_name = 'evento'
        verbose_name_plural = 'eventos'

class PerroGrande(models.Model):
    totle = models.TextField(default='Titulo evento')
    detalle = models.TextField('Descripcion', blank=True, null=True)
    foto_pichicho = models.ImageField(verbose_name='Foto de evento', upload_to='evebt_pictures', blank=True, null=True)

    def __str__(self):
        return self.title

    class Meta:
        verbose_name = 'evento'
        verbose_name_plural = 'eventos'
        
class Gato(models.Model):
    title = models.TextField(default='Titulo evento')
    description = models.TextField('Descripcion', blank=True, null=True)
    event_picture = models.ImageField(verbose_name='Foto de evento', upload_to='evebt_pictures', blank=True, null=True)

    def __str__(self):
        return self.title

    class Meta:
        verbose_name = 'evento'
        verbose_name_plural = 'eventos'


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-easy-drf", # Replace with your own username
    version="0.0.3",
    scripts=['bin/easy-drf'],
    author="Pablo Pissi",
    author_email="pablopissi@gmail.com",
    description="A package to create boring stuff of django rest framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pablop94/django-easy-drf",
    packages=['lib'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)